@@ -1,6 +1,6 @@
 package Net::SFTP::Foreign::Compat;
 
-our $VERSION = '1.70_04';
+our $VERSION = '1.70_05';
 
 use warnings;
 use strict;
@@ -37,17 +37,18 @@ sub import {
     }
 }
 
-our %DEFAULTS = ( put => [],
-                  get => [],
+our %DEFAULTS = ( put => [best_effort => 1],
+                  get => [best_effort => 1],
                   ls  => [],
                   new => [] );
 
 BEGIN {
-    my @forbidden = qw( setcwd cwd open opendir sftpread sftpwrite seek
-                        tell eof write flush read getc lstat stat fstat
-                        remove rmdir mkdir setstat fsetstat close closedir
-                        readdir realpath readlink rename symlink abort
-                        get_content join glob rremove rget rput error );
+    my @forbidden = qw( setcwd cwd open opendir sftpread sftpwrite
+                        seek tell eof write flush read getc lstat stat
+                        fstat remove rmdir mkdir setstat fsetstat
+                        close closedir readdir realpath readlink
+                        rename symlink abort get_content join glob
+                        rremove rget rput error die_on_error );
 
     for my $method (@forbidden) {
         my $super = "SUPER::$method";
@@ -101,21 +102,25 @@ sub status {
 }
 
 sub get {
-    croak '$Usage: $sftp->get($local, $remote, $cb)' if @_ < 3 or @_ > 4;
+    croak '$Usage: $sftp->get($local, $remote, $cb)' if @_ < 2 or @_ > 4;
     my ($sftp, $remote, $local, $cb) = @_;
 
     my $save = defined(wantarray);
     my @content;
+    my @cb;
+    if (defined $cb or $save) {
+        @cb = ( callback => sub {
+                    my ($sftp, $data, $off, $size) = @_;
+                    $cb->($sftp, $data, $off, $size) if $cb;
+                    push @content, $data if $save
+                });
+    }
 
     $sftp->SUPER::get($remote, $local,
                       @{$DEFAULTS{get}},
-		      dont_save => !defined($local),
-		      callback => sub {
-			  my ($sftp, $data, $off, $size) = @_;
-			  $cb->($sftp, $data, $off, $size) if $cb;
-			  push @content, $data if $save
-		      } )
-	or return undef;
+                      dont_save => !defined($local),
+                      @cb)
+        or return undef;
 
     if ($save) {
 	return CORE::join('', @content);
@@ -128,7 +133,7 @@ sub put {
 
     $sftp->SUPER::put($local, $remote,
                       @{$DEFAULTS{put}},
-		      (defined $cb ? (callback => $cb) : ()));
+		      callback => $cb);
     $sftp->_warn_error;
     !$sftp->SUPER::error;
 }
@@ -184,7 +189,7 @@ sub _gen_do_and_status {
 *do_write = _gen_do_and_status('sftpwrite');
 *do_close = _gen_do_and_status('close');
 *do_setstat = _gen_do_and_status('setstat');
-*do_fsetstat = _gen_do_and_status('fsetstat');
+*do_fsetstat = _gen_do_and_status('setstat');
 *do_remove = _gen_do_and_status('remove');
 *do_rename = _gen_do_and_status('rename');
 *do_mkdir = _gen_do_and_status('mkdir');
